==> hbase-2.4.9-src.tar.gz: hbase-2.4.9/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/model/StorageClusterVersionModel.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.rest.model;

import java.io.Serializable;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.yetus.audience.InterfaceAudience;

/**
 * Simple representation of the version of the storage cluster
 * 
 * <pre>
 * &lt;complexType name="StorageClusterVersion"&gt;
 *   &lt;attribute name="version" type="string"&gt;&lt;/attribute&gt;
 * &lt;/complexType&gt;
 * </pre>
 */
@XmlRootElement(name="ClusterVersion")
@InterfaceAudience.Private
public class StorageClusterVersionModel implements Serializable {
  private static final long serialVersionUID = 1L;

  private String version;

  /**
   * @return the storage cluster version
   */
  @XmlAttribute(name="Version")
  public String getVersion() {
    return version;
  }

  /**
   * @param version the storage cluster version
   */
  public void setVersion(String version) {
    this.version = version;
  }

  /* (non-Javadoc)
   * @see java.lang.Object#toString()
   */
  @Override
  public String toString() {
    return version;
  }

  //needed for jackson deserialization
  private static StorageClusterVersionModel valueOf(String value) {
    StorageClusterVersionModel versionModel
        = new StorageClusterVersionModel();
    versionModel.setVersion(value);
    return versionModel;
  }
}

==> hbase-2.4.13-src.tar.gz: hbase-2.4.13/hbase-rest/src/main/java/org/apache/hadoop/hbase/rest/model/StorageClusterVersionModel.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.rest.model;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Simple representation of the version of the storage cluster
 *
 * <pre>
 * &lt;complexType name="StorageClusterVersion"&gt;
 *   &lt;attribute name="version" type="string"&gt;&lt;/attribute&gt;
 * &lt;/complexType&gt;
 * </pre>
 */
@XmlRootElement(name = "ClusterVersion")
@InterfaceAudience.Private
public class StorageClusterVersionModel implements Serializable {
  private static final long serialVersionUID = 1L;

  private String version;

  /**
   * @return the storage cluster version
   */
  @XmlAttribute(name = "Version")
  public String getVersion() {
    return version;
  }

  /**
   * @param version the storage cluster version
   */
  public void setVersion(String version) {
    this.version = version;
  }

  /*
   * (non-Javadoc)
   * @see java.lang.Object#toString()
   */
  @Override
  public String toString() {
    return version;
  }

  // needed for jackson deserialization
  private static StorageClusterVersionModel valueOf(String value) {
    StorageClusterVersionModel versionModel = new StorageClusterVersionModel();
    versionModel.setVersion(value);
    return versionModel;
  }
}
